[llvm-commits] CVS: llvm/include/llvm/Transforms/Utils/ Local.h

Christopher Lattner lattner at cs.uiuc.edu
Thu Sep 5 21:36:02 PDT 2002


Changes in directory llvm/include/llvm/Transforms/Utils:

Local.h updated: 1.6 -> 1.7

---
Log message:

- Rename BreakCriticalEdge to the slightly more standard SplitCriticalEdge



---
Diffs of the changes:

Index: llvm/include/llvm/Transforms/Utils/Local.h
diff -u llvm/include/llvm/Transforms/Utils/Local.h:1.6 llvm/include/llvm/Transforms/Utils/Local.h:1.7
--- llvm/include/llvm/Transforms/Utils/Local.h:1.6	Thu Sep  5 21:19:25 2002
+++ llvm/include/llvm/Transforms/Utils/Local.h	Thu Sep  5 21:35:11 2002
@@ -68,10 +68,11 @@
 ///
 bool isCriticalEdge(const TerminatorInst *TI, unsigned SuccNum);
 
 /// BreakCriticalEdge - Insert a new node node to split the critical edge.  This
 /// will update DominatorSet and DominatorTree information if it is available,
 /// thus calling this pass will not invalidate either of them.
 ///
-void BreakCriticalEdge(TerminatorInst *TI, unsigned SuccNum, Pass *P = 0);
+void SplitCriticalEdge(TerminatorInst *TI, unsigned SuccNum, Pass *P = 0);
 
 #endif
@@ -68,10 +68,11 @@
 bool isCriticalEdge(const TerminatorInst *TI, unsigned SuccNum);
 
-/// BreakCriticalEdge - Insert a new node node to split the critical edge.  This
-/// will update DominatorSet and DominatorTree information if it is available,
-/// thus calling this pass will not invalidate either of them.
+/// SplitCriticalEdge - Insert a new node node to split the critical edge.  This
+/// will update DominatorSet, ImmediateDominator and DominatorTree information
+/// if it is available, thus calling this pass will not invalidate either of
+/// them.
 ///





More information about the llvm-commits mailing list